@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: cryptohash-conduit
 version: 0.1.1
-id: cryptohash-conduit-0.1.1-e4bade99c5dbc09eaccf1f4fc13e0864
-key: crypt_0D42bvzqonC7duxZ9avsAD
+id: cryptohash-conduit-0.1.1-dec777bba26b4960028433a6d8dd1c26
+key: crypt_7CEKgprLIcLE81SQPZ0PwA
 license: BSD3
 copyright: Vincent Hanquez <vincent@snarc.org>
 maintainer: vincent@snarc.org
@@ -22,14 +22,14 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/cryptohash-conduit-0.1.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/cryptohash-conduit-0.1.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/cryptohash-conduit-0.1.1
-hs-libraries: HScryptohash-conduit-0.1.1-0D42bvzqonC7duxZ9avsAD
+hs-libraries: HScryptohash-conduit-0.1.1-7CEKgprLIcLE81SQPZ0PwA
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.1-0dc23cc567e1e45fd451d3d7a1cbf2ca
-    conduit-extra-1.1.9.2-79e9518024a2df5c3adcf7d7df9fbea5
+    conduit-1.2.6.1-20c379c1e33e978c5d5c8f5ef78dd0c3
+    conduit-extra-1.1.9.2-aa4a80a63306500e6d6a1edce4badfdd
     cryptohash-0.11.6-e28406db011dea16e99b7bc1708b91dc
-    resourcet-1.1.7.1-53b70bd9a277fdc9d256cfbf9605d278
+    resourcet-1.1.7.1-34b9e931a3d19e984bea5de562a18bbd
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
 haddock-interfaces: /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock
 haddock-html: /usr/share/doc/haskell-cryptohash-conduit/html
